pub enum PlistParseError {
Show 15 variants
MissingKey(String),
NoValueAtIndex(usize),
InvalidType(String, String),
InvalidTypeIndex(usize, String),
InvalidDictionarySize(usize, usize),
UidOutOfRange(u64),
NoPayload,
WrongMessageType,
InvalidEditedMessage(String),
StreamTypedError(StreamTypedError),
TypedStreamError(TypedStreamError),
HandwritingError(HandwritingError),
DigitalTouchError(DigitalTouchError),
PollError,
RecursionLimit,
}Expand description
Errors that can happen when parsing the plist data stored in the payload_data field
Variants
MissingKey(String)
Expected key was not found in the plist data
NoValueAtIndex(usize)
No value was found at the specified index
InvalidType(String, String)
Value had an incorrect type for the specified key
InvalidTypeIndex(usize, String)
Value had an incorrect type at the specified index
InvalidDictionarySize(usize, usize)
Dictionary has mismatched number of keys and values
UidOutOfRange(u64)
UID value cannot be represented as an object-table index on this target.
NoPayload
No payload data was found
WrongMessageType
Message is not of the expected type
InvalidEditedMessage(String)
Could not parse an edited message
StreamTypedError(StreamTypedError)
Error from stream typed parsing
TypedStreamError(TypedStreamError)
Error from typedstream parsing
HandwritingError(HandwritingError)
Error from handwriting data parsing
DigitalTouchError(DigitalTouchError)
Error from Digital Touch data parsing
PollError
Error parsing a poll message
RecursionLimit
Exceeded the maximum UID-reference resolution depth (likely a reference cycle)