App messages are messages that developers can generate with their apps. Some built-in functionality also uses App Messages, like Apple Pay or Handwriting.
Structs
- AppMessage
- This struct represents Apple’s
MSMessageTemplateLayout.
Enums
- Check
InKind - One of the three metadata states a Check In balloon can advertise. The
variant choice mirrors the query-string key the timestamp came from
(
estimatedEndTime,triggerTime,sendDate).