pub struct EditedEvent {
pub date: i64,
pub text: String,
pub components: Vec<BubbleComponent>,
pub guid: Option<String>,
}Expand description
Represents a single edit event for a message part
Fields
date: i64The date the message part was edited
text: StringThe content of the edited message part, deserialized from the
typedstream format.
components: Vec<BubbleComponent>The parsed typedstream component data used to add attributes to the message text
guid: Option<String>A GUID reference to another message