Module expressives

Module expressives 

Expressives are effects that you can select by tapping and holding the send button.

The data is stored on messages through the expressive_send_style_id field.

Enums

BubbleEffect
Bubble effects are effects that alter the display of the chat bubble.
Expressive
Parsed value of a message’s expressive_send_style_id.
ScreenEffect
Screen effects are effects that alter the entire background of the message view.