BubbleEffect

Enum BubbleEffect 

pub enum BubbleEffect {
    Slam,
    Loud,
    Gentle,
    InvisibleInk,
}
Bubble effects are effects that alter the display of the chat bubble.

Read more here.

Variants



Slam

Creates a slam effect that makes the bubble appear to slam down onto the screen.



Loud

Creates a loud effect that makes the bubble appear to enlarge temporarily.



Gentle

Creates a gentle effect that makes the bubble appear to shrink temporarily.



InvisibleInk

Creates an invisible ink effect that hides the message until the recipient swipes over it.