pub enum StickerSource {
Genmoji,
Memoji,
UserGenerated,
App(String),
}Expand description
Source that created a sticker attachment.
Variants
Genmoji
A Genmoji
Memoji
A Memoji
UserGenerated
User-created sticker.
App(String)
Sticker from an iMessage sticker app.
Implementations
Sourceimpl StickerSource
impl StickerSource
Sourcepub fn from_bundle_id(bundle_id: &str) -> Option<Self>
pub fn from_bundle_id(bundle_id: &str) -> Option<Self>
Resolve a sticker source from the sticker app bundle ID.
Example
use imessage_database::message_types::sticker::StickerSource;
println!("{:?}", StickerSource::from_bundle_id("com.apple.messages.genmoji")); // Some(Genmoji)Trait Implementations
Sourceimpl Debug for StickerSource
impl Debug for StickerSource
impl Eq for StickerSource
Sourceimpl PartialEq for StickerSource
impl PartialEq for StickerSource
Sourcefn eq(&self, other: &StickerSource) -> bool
fn eq(&self, other: &StickerSource) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for StickerSource