Link previews iMessage generates when sending links.
They may contain metadata, even if the page the link points to no longer exists on the internet.
Structs
- URLMessage
- This struct is not documented by Apple, but represents messages created by
com.apple.messages.URLBalloonProvider.