pub struct URLMessage<'a> {
pub title: Option<&'a str>,
pub summary: Option<&'a str>,
pub url: Option<&'a str>,
pub original_url: Option<&'a str>,
pub item_type: Option<&'a str>,
pub images: Vec<&'a str>,
pub icons: Vec<&'a str>,
pub site_name: Option<&'a str>,
pub placeholder: bool,
}Expand description
This struct is not documented by Apple, but represents messages created by
com.apple.messages.URLBalloonProvider.
Fields
title: Option<&'a str>The webpage’s <og:title> attribute
summary: Option<&'a str>The webpage’s <og:description> attribute
url: Option<&'a str>URL that served the preview content.
original_url: Option<&'a str>Original URL before redirects.
item_type: Option<&'a str>Apple-provided item type.
images: Vec<&'a str>Up to 4 image previews displayed in the background of the bubble
icons: Vec<&'a str>Website icon URLs.
site_name: Option<&'a str>Website name.
placeholder: booltrue when Messages stored the link as an unloaded placeholder preview.
Implementations
Sourceimpl<'a> URLMessage<'a>
impl<'a> URLMessage<'a>
Sourcepub fn get_url_message_override(
payload: &'a Value,
) -> Result<URLOverride<'a>, PlistParseError>
pub fn get_url_message_override( payload: &'a Value, ) -> Result<URLOverride<'a>, PlistParseError>
Parse the concrete URL-balloon subtype from the payload.
Sourcepub fn get_url(&self) -> Option<&str>
pub fn get_url(&self) -> Option<&str>
Resolve this message’s URL via HasUrl::get_url.