Module variants

Module variants 

Message classification helpers for rows from the message table.

Enums

Announcement
Non-balloon announcement represented by a message row.
CustomBalloon
iMessage app balloon kind.
Tapback
Tapbacks
TapbackAction
Whether a tapback was added or removed.
URLOverride
Specialized payload carried by a URL balloon.
Variant
High-level classification for a message row.

Traits

BalloonProvider
Parser for custom balloon payloads stored in message plist data.
HasUrl
URL fields shared by payloads that store both final and original URLs.