pub enum Announcement<'a> {
FullyUnsent,
GroupAction(GroupAction<'a>),
AudioMessageKept,
Unknown(&'a i32),
}Expand description
Announcement Message Types
Announcements are messages sent to a thread for actions that are not balloons, i.e. updating the name of the group or changing the group photo
Variants
FullyUnsent
All parts of the message were unsent
GroupAction(GroupAction<'a>)
A group action
AudioMessageKept
A user kept an audio message
Unknown(&'a i32)
Types that may occur in the future