Tapback

Enum Tapback 

pub enum Tapback<'a> {
    Loved,
    Liked,
    Disliked,
    Laughed,
    Emphasized,
    Questioned,
    Emoji(Option<&'a str>),
    Sticker,
}
Tapbacks

Tapbacks look like normal messages in the database. Only the latest tapback state is stored. For example:

  • user receives message -> user likes message
    • This creates a message and a like message.
  • user receives message -> user likes message -> user unlikes message
    • This creates a message and a like message.
    • The like message is removed when the unlike message arrives.
    • Removed rows leave gaps in ROWID; the row ID is not reused.
    • The database keeps the latest tapback state, not the full tapback history.

Technical detail

The index specified by the prefix maps to the index of the body part given by Message::parse_body().

  • bp: GUID prefix for bubble message tapbacks (url previews, apps, etc).
  • p:0/ GUID prefix for normal messages (body text, attachments).

If a message has 3 attachments followed by some text:

  • 0 is the first image
  • 1 is the second image
  • 2 is the third image
  • 3 is the text of the message

In this example, a Like on p:2/ is a like on the third image.

Variants



Loved

Heart



Liked

Thumbs up



Disliked

Thumbs down



Laughed

Laughing face



Emphasized

Exclamation points



Questioned

Question marks



Emoji(Option<&'a str>)

Custom emoji tapbacks



Sticker

Custom sticker tapbacks