Variant

Enum Variant 

pub enum Variant<'a> {
    Normal,
    Edited,
    Tapback(usize, TapbackAction, Tapback<'a>),
    App(CustomBalloon<'a>),
    SharePlay,
    Vote,
    PollUpdate,
    Unknown(i32),
}
Message variant container

Messages can exist as one of many different variants, this encapsulates all of the possibilities.

Variants



Normal

An iMessage with a standard text body that may include attachments



Edited

A message that has been edited or unsent



Tapback(usize, TapbackAction, Tapback<'a>)

A tapback

The usize indicates the index of the message’s parse_body() the tapback is applied to.



App(CustomBalloon<'a>)

An iMessage app generated message



SharePlay

A SharePlay message



Vote

A vote cast on a poll



PollUpdate

A new option sent to a poll



Unknown(i32)

Container for new or unknown messages