pub struct Properties {
pub read_receipts_enabled: bool,
pub last_message_guid: Option<String>,
pub forced_sms: bool,
pub group_photo_guid: Option<String>,
pub has_chat_background: bool,
}Expand description
Chat properties are stored as a plist in the database
This represents the metadata for a chatroom
Fields
read_receipts_enabled: boolWhether the chat has read receipts enabled
last_message_guid: Option<String>The most recent message in the chat
forced_sms: boolWhether the chat was forced to use SMS/RCS instead of iMessage
group_photo_guid: Option<String>GUID of the group photo, if it exists in the attachments table
has_chat_background: boolWhether the chat has a custom background image