Module imessage_database::tables::chat_handle
source · Expand description
This module represents the chat to handle join table.
Structs
- Represents a single row in the
chat_handle_jointable.
This module represents the chat to handle join table.
chat_handle_join table.