AttachmentDiagnostic

Struct AttachmentDiagnostic 

pub struct AttachmentDiagnostic {
    pub total_attachments: usize,
    pub total_bytes_referenced: u64,
    pub total_bytes_on_disk: u64,
    pub missing_files: usize,
    pub no_path_provided: usize,
}
Diagnostic data for the attachment table

Fields

total_attachments: usize

The total number of attachments in the table

total_bytes_referenced: u64

The sum of total_bytes for all attachments referenced in the table

total_bytes_on_disk: u64

The total size of attachment files present on disk

missing_files: usize

The number of attachments with missing files (no path or file not found)

no_path_provided: usize

The number of attachments with no path provided in the table

Implementations

Source

impl AttachmentDiagnostic

pub fn no_file_located(&self) -> usize

The number of attachments where a path was provided but no file was found at that location

pub fn missing_percent(&self) -> Option<f64>

The percentage of attachments that are missing, or None if there are no attachments