ParsedBody

Struct ParsedBody 

pub struct ParsedBody {
    pub text: Option<String>,
    pub components: Vec<BubbleComponent>,
    pub edited_parts: Option<EditedMessage>,
    pub balloon_bundle_id: Option<String>,
}
The result of parsing a message body via Message::parse_body().

Use Message::apply_body() to apply the parsed body back to the message:

if let Ok(body) = message.parse_body(&conn) {
    message.apply_body(body);
}

Fields

text: Option<String>

The text content of the message

components: Vec<BubbleComponent>

The components that make up the message body

edited_parts: Option<EditedMessage>

The components of the message that may have been edited or unsent

balloon_bundle_id: Option<String>

The resolved balloon bundle ID, which may differ from the original