Module imessage_database::tables::messages::models

source ·
This module contains Data structures and models that represent message data.

Structs

Enums

  • Defines the parts of a message bubble, i.e. the content that can exist in a single message.
  • Defines different types of services we can receive messages from.