get_local_time

Function get_local_time 

pub fn get_local_time(
    date_stamp: i64,
    offset: i64,
) -> Result<DateTime<Local>, MessageError>
Create a DateTime<Local> from an arbitrary date and offset

This is used to create date data for anywhere dates are stored in the table, including PLIST payloads or typedstream data.

Example

use imessage_database::util::dates::{get_local_time, get_offset};

let current_offset = get_offset();
let local = get_local_time(674526582885055488, current_offset).unwrap();