iMessages can represent different kinds of data. This module defines types for those data.
Modules
- app
- App messages are messages that developers can generate with their apps. Some built-in functionality also uses App Messages, like Apple Pay or Handwriting.
- app_
store - App Store link previews stored in URL balloon payloads.
- business_
chat - Apple Business Chat payload parsers.
- collaboration
- Collaboration link previews generated by apps such as Pages and Freeform.
- digital_
touch - Digital Touch messages are animated sketches, taps, fireballs, kisses, and heartbeats, as well as still photos with optional drawing overlays and videos.
- edited
- Edited and unsent message metadata from
message_summary_info. - expressives
- Expressives are effects that you can select by tapping and holding the send button.
- handwriting
- Handwritten messages are animated doodles or messages sent in your own handwriting.
- music
- Apple Music link previews stored in URL balloon payloads.
- placemark
- Maps link previews stored in URL balloon payloads.
- polls
- Poll payloads generated by the Messages Polls app.
- sticker
- These are sticker messages, either from the user’s sticker library or sticker apps.
- text_
effects - Formatting and detector metadata attached to message body text.
- translation
- Translation metadata stored in
message_summary_info. - url
- Link previews iMessage generates when sending links.
- variants
- Message classification helpers for rows from the
messagetable.