EditedMessage

Struct EditedMessage 

pub struct EditedMessage {
    pub parts: Vec<EditedMessagePart>,
}
Parsed edit metadata for every body part in a message.

Internal Representation

Edited or unsent messages are stored with a NULL text field. Edited messages include message_summary_info that contains a dictionary with message body part data, including typedstream-encoded edit history. The order of entries in the edit history represents the order the part changed: item 0 is the original text and the last item is the current text.

Message Body Parts

  • otr: dictionary of message part indexes.
  • rp: list of unsent message part indexes.
  • ec: dictionary of edited message part indexes to edit history arrays.
  • Each ec item stores d (edit timestamp) and t (edited attributedBody typedstream).

Documentation

Apple describes editing and unsending messages here.

Fields

parts: Vec<EditedMessagePart>

One entry per message body part.

Implementations

Source

impl EditedMessage

pub fn part(&self, index: usize) -> Option<&EditedMessagePart>

Return edit metadata for the given body part index.

pub fn is_unedited_at(&self, index: usize) -> bool

true when the given body part exists and has not been edited or unsent.

pub fn items(&self) -> usize

Number of body parts tracked by this edit payload.