pub struct EditedMessage {
pub parts: Vec<EditedMessagePart>,
}Expand description
Parsed edit metadata for every body part in a message.
Internal Representation
Edited or unsent messages are stored with a NULL text field.
Edited messages include message_summary_info that contains a dictionary
with message body part data, including typedstream-encoded
edit history. The order of entries in the edit history represents the order
the part changed: item 0 is the original text and the last item is the
current text.
Message Body Parts
otr: dictionary of message part indexes.rp: list of unsent message part indexes.ec: dictionary of edited message part indexes to edit history arrays.- Each
ecitem storesd(edit timestamp) andt(editedattributedBodytypedstream).
Documentation
Apple describes editing and unsending messages here.
Fields
parts: Vec<EditedMessagePart>One entry per message body part.
Implementations
Sourceimpl EditedMessage
impl EditedMessage
Sourcepub fn part(&self, index: usize) -> Option<&EditedMessagePart>
pub fn part(&self, index: usize) -> Option<&EditedMessagePart>
Return edit metadata for the given body part index.
Sourcepub fn is_unedited_at(&self, index: usize) -> bool
pub fn is_unedited_at(&self, index: usize) -> bool
true when the given body part exists and has not been edited or unsent.