Representations of iMessage database tables as structs.
Many of these tables do not include all available columns. Even on the same versions of macOS, the schema of the iMessage database can vary.
Modules
- attachment
- Attachment table rows and attachment file path helpers.
- chat
- Chat table rows and chat metadata helpers.
- chat_
handle - Chat-to-handle join table helpers.
- diagnostic
- Diagnostic result types for Messages database tables.
- handle
- Handle table rows and handle deduplication helpers.
- messages
- Data structures and models used to parse and represent message data.
- table
- Table traits, database connection helpers, and shared table constants.