Module tables

Module tables 

Representations of iMessage database tables as structs.

Many of these tables do not include all available columns. Even on the same versions of macOS, the schema of the iMessage database can vary.

Modules

attachment
This module represents common (but not all) columns in the attachment table.
chat
This module represents common (but not all) columns in the chat table.
chat_handle
This module represents the chat to handle join table.
diagnostic
This module contains data structures returned by diagnostic queries on iMessage database tables.
handle
This module represents common (but not all) columns in the handle table.
messages
Data structures and models used to parse and represent message data.
table
This module defines traits for table representations and stores some shared table constants.