pub struct Chat {
pub rowid: i32,
pub chat_identifier: String,
pub service_name: Option<String>,
pub display_name: Option<String>,
}Expand description
Represents a single row in the chat table.
Fields
rowid: i32The unique identifier for the chat in the database
chat_identifier: StringThe identifier for the chat, typically a phone number, email, or group chat ID
service_name: Option<String>The service the chat used, i.e. iMessage, SMS, IRC, etc.
display_name: Option<String>Optional custom name created for the chat
Implementations
Sourceimpl Chat
impl Chat
Sourcepub fn name(&self) -> &str
pub fn name(&self) -> &str
Generate a name for a chat, falling back to the default if a custom one is not set
Sourcepub fn display_name(&self) -> Option<&str>
pub fn display_name(&self) -> Option<&str>
Get the current display name for the chat, if it exists.
Sourcepub fn service(&self) -> Service<'_>
pub fn service(&self) -> Service<'_>
Get the service used by the chat, i.e. iMessage, SMS, IRC, etc.
Sourcepub fn properties(&self, db: &Connection) -> Option<Properties>
pub fn properties(&self, db: &Connection) -> Option<Properties>
Get the Properties for the chat, if they exist
Calling this hits the database, so it is expensive and should only get invoked when needed.