pub struct AttachmentDiagnostic {
pub total_attachments: usize,
pub total_bytes_referenced: u64,
pub total_bytes_on_disk: u64,
pub missing_files: usize,
pub no_path_provided: usize,
}Expand description
Diagnostic data for the attachment table.
Fields
total_attachments: usizeTotal attachments in the table.
total_bytes_referenced: u64Sum of total_bytes for all attachment rows.
total_bytes_on_disk: u64Total size of attachment files present on disk.
missing_files: usizeAttachments with no path or no file at the resolved path.
no_path_provided: usizeAttachments with no path in the table.
Implementations
Sourceimpl AttachmentDiagnostic
impl AttachmentDiagnostic
Sourcepub fn no_file_located(&self) -> usize
pub fn no_file_located(&self) -> usize
Attachments with a path but no file at that location.
Sourcepub fn missing_percent(&self) -> Option<f64>
pub fn missing_percent(&self) -> Option<f64>
Percentage of attachments that are missing.