Module imessage_database::tables::messages::models
source · Expand description
This module contains Data structures and models that represent message data.
Structs
- Defines ranges of text and associated attributes parsed from
typedstreamattributedBodydata.
Enums
- Defines the parts of a message bubble, i.e. the content that can exist in a single message.
- Defines different types of services we can receive messages from.